import 'dart:async';

import 'package:analytics_example/login_screen.dart';
import 'package:di_analytics/di_analytics.dart';
import 'package:flutter/material.dart';

class MainScreen extends StatefulWidget {
  const MainScreen({Key? key}) : super(key: key);

  @override
  _MainScreenState createState() => _MainScreenState();
}

class _MainScreenState extends State<MainScreen> {
  bool _autoLogging = false;
  Timer? _timer;
  @override
  void initState() {
    super.initState();
    DIAnalytics.instance.setUser("uid_1", info: {"name": "John"});

    DIAnalytics.instance.addSharedParameters({
      "param_2": null,
    });
  }

  @override
  void dispose() {
    _timer?.cancel();
    super.dispose();
  }

  void _logAnEvent() {
    var params = {"a param": 1};
    DIAnalytics.instance.logEvent("main_screen_event", parameters: params);
  }

  void _dispatchNow() {
    DIAnalytics.instance.dispatchEvents();
  }

  void _reset() {
    DIAnalytics.instance.resetAnalyticsData();
  }

  void _autoLogEvent() {
    if (_autoLogging) {
      _timer?.cancel();
      _timer = null;
    } else {
      _timer = Timer.periodic(const Duration(seconds: 1), (_) {
        DIAnalytics.instance.logEvent("auto_event");
      });
    }
    setState(() {
      _autoLogging = !_autoLogging;
    });
  }

  void _logout() {
    DIAnalytics.instance.logEvent("tap_btn_logout");
    DIAnalytics.instance.setUser(null);

    Navigator.of(context).pushAndRemoveUntil(
        MaterialPageRoute(builder: (context) => const LoginScreen()),
        (route) => false);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SizedBox(
        width: double.infinity,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            TextButton(
              onPressed: _logAnEvent,
              child: const Text("Log an event"),
            ),
            TextButton(
              onPressed: _dispatchNow,
              child: const Text("Dispatch now"),
            ),
            TextButton(
              onPressed: _reset,
              child: const Text("Reset"),
            ),
            TextButton(
                onPressed: _autoLogEvent,
                child: Text(_autoLogging
                    ? "Stop auto log events"
                    : "Start auto log events")),
            TextButton(
              onPressed: _logout,
              child: const Text("Logout"),
            )
          ],
        ),
      ),
    );
  }
}
